@@ -19,10 +19,12 @@
 
 from typing import Union
 
-from qgis.core import QgsGeometry, QgsLineString
+from qgis.core import QgsAbstractGeometry, QgsGeometry
 
 
-def clone_geometry_safely(geometry: Union[QgsGeometry, QgsLineString]) -> QgsGeometry:
+def clone_geometry_safely(
+    geometry: Union[QgsGeometry, QgsAbstractGeometry]
+) -> QgsGeometry:
     if isinstance(geometry, QgsGeometry):
         original_abstract_geometry = geometry.get()
         cloned_original_abstract_geometry = original_abstract_geometry.clone()
